powered by
Computes pairwise sums.
pair.sum(X)
a numeric matrix.
Matrix containing the sums.
The function computes all sums of row i and row j with i < j. The function is a wrapper to a C function to do the computation quickly and does no checks concerning the input.
pair.diff, pair.prod
pair.diff
pair.prod
# NOT RUN { X <- matrix(1:10, ncol = 2, byrow = FALSE) pair.sum(X) # }
Run the code above in your browser using DataLab