an optional matrix giving the starting value for the iteration. Otherwise the regular covariance is used after transforming it to a shape matrix wit determinant 1.
steps
a fixed number of iteration steps to take. See details.
eps
convergence tolerance.
maxiter
maximum number of iterations.
in.R
logical. If TRUE R-code (and not C) is used in the iteration
na.action
a function which indicates what should happen when the data
contain 'NA's. Default is to fail.
D<U+2D8A796E>'s shape matrix can be seen as tyler.shape's matrix wrt to the origin for the pairwise differences of the observations.
Therefore this shape matrix needs no location parameter.
The function is, however, slow if the dataset is large.
The algorithm also allows for a k-step version where the iteration is run for a fixed number of steps instead of until convergence. If steps is finite that number of steps is taken and maxiter is ignored.
A better implementation is available in the package fastM as the function DUEMBGENshape.
References
D<U+2D8A796E>, L. (1998), On Tyler's M-functional of scatter in high dimension, Annals of Institute of Statistical Mathematics, 50, 471--491.