Function to compute the Hodges - Lehmann estimator of location in the one sample case.
Usage
hl.loc(x, na.action = na.fail)
Arguments
x
a numeric vector.
na.action
a function which indicates what should happen when the data
contain 'NA's. Default is to fail.
Value
the Hodges - Lehmann estimator of location.
Details
The Hodges - Lehmann estimator is the median of the combined data points and Walsh averages.
It is the same as the Pseudo Median returned as a by-product of the function wilcox.test.